==> huaweicloudsdkgaussdb-3.1.47-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/proxy_update_proxy_connection_pool_type_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ProxyUpdateProxyConnectionPoolTypeRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'connection_pool_type': 'str'
    }

    attribute_map = {
        'connection_pool_type': 'connection_pool_type'
    }

    def __init__(self, connection_pool_type=None):
        """ProxyUpdateProxyConnectionPoolTypeRequest

        The model defined in huaweicloud sdk

        :param connection_pool_type: 连接池类型。CLOSED：关闭连接池；SESSION：开启会话级连接池
        :type connection_pool_type: str
        """
        
        

        self._connection_pool_type = None
        self.discriminator = None

        self.connection_pool_type = connection_pool_type

    @property
    def connection_pool_type(self):
        """Gets the connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.

        连接池类型。CLOSED：关闭连接池；SESSION：开启会话级连接池

        :return: The connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.
        :rtype: str
        """
        return self._connection_pool_type

    @connection_pool_type.setter
    def connection_pool_type(self, connection_pool_type):
        """Sets the connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.

        连接池类型。CLOSED：关闭连接池；SESSION：开启会话级连接池

        :param connection_pool_type: The connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.
        :type connection_pool_type: str
        """
        self._connection_pool_type = connection_pool_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProxyUpdateProxyConnectionPoolTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.75-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/proxy_update_proxy_connection_pool_type_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ProxyUpdateProxyConnectionPoolTypeRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'connection_pool_type': 'str'
    }

    attribute_map = {
        'connection_pool_type': 'connection_pool_type'
    }

    def __init__(self, connection_pool_type=None):
        """ProxyUpdateProxyConnectionPoolTypeRequest

        The model defined in huaweicloud sdk

        :param connection_pool_type: 连接池类型。 - CLOSED：关闭连接池。 - SESSION：开启会话级连接池
        :type connection_pool_type: str
        """
        
        

        self._connection_pool_type = None
        self.discriminator = None

        self.connection_pool_type = connection_pool_type

    @property
    def connection_pool_type(self):
        """Gets the connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.

        连接池类型。 - CLOSED：关闭连接池。 - SESSION：开启会话级连接池

        :return: The connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.
        :rtype: str
        """
        return self._connection_pool_type

    @connection_pool_type.setter
    def connection_pool_type(self, connection_pool_type):
        """Sets the connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.

        连接池类型。 - CLOSED：关闭连接池。 - SESSION：开启会话级连接池

        :param connection_pool_type: The connection_pool_type of this ProxyUpdateProxyConnectionPoolTypeRequest.
        :type connection_pool_type: str
        """
        self._connection_pool_type = connection_pool_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProxyUpdateProxyConnectionPoolTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
